==> zn-plugin-workflow-0.1.5.tgz: package/src/service/WFSchemaService.js <==
zn.define(['node:http'], function (http) {

    return zn.Class({
        methods: {
            init: function (store){
                this._store = store;
            },
            getSessionId: function (){
                if(zn._request){
                    return zn._request.getSessionValueByKey('id');
                }else if(zn._oldRequest) {
                    return zn._oldRequest.getSessionValueByKey('id');
                }else {
                    return 0;
                }
            },
            doAction: function (action, form){
                switch (action._type) {
                    case "__url":
                        var _value = action._value;
                        if(_value.indexOf('http') == -1){
                            _value = zn.SERVER_URL + _value;
                        }
                        http.get(_value + "?ticket_id=" + form.id);
                        break;
                    case "__message":

                        break;
                    case "__email":

                        break;
                    case "__sms":

                        break;
                }
            },
            doActions: function (actions, form){
                var _defer = zn.async.defer(),
                    _actions = actions || [];
                _actions.forEach(function (action, index){
                    this.doAction(action, form);
                }.bind(this));

                return _defer.promise;
            }
        }
    });

});

==> zn-plugin-workflow-0.2.0.tgz: package/src/service/WFSchemaService.js <==
zn.define(['node:http'], function (http) {

    return zn.Class({
        methods: {
            init: function (store){
                this._store = store;
            },
            getSessionId: function (){
                if(zn._request){
                    return zn._request.getSessionValueByKey('id');
                }else if(zn._oldRequest) {
                    return zn._oldRequest.getSessionValueByKey('id');
                }else {
                    return 0;
                }
            },
            doAction: function (action, form, instanceId){
                switch (action._type) {
                    case "__url":
                        var _value = action._value;
                        if(_value.indexOf('http') == -1){
                            _value = zn.SERVER_URL + _value;
                        }
                        http.get(_value + "?ticket_id=" + form.id + "&instance_id=" + instanceId);
                        break;
                    case "__message":

                        break;
                    case "__email":

                        break;
                    case "__sms":

                        break;
                }
            },
            doActions: function (actions, form, instanceId){
                var _defer = zn.async.defer(),
                    _actions = actions || [];
                _actions.forEach(function (action, index){
                    this.doAction(action, form, instanceId);
                }.bind(this));

                return _defer.promise;
            }
        }
    });

});
